

{- |
Copyright  : Will Thompson, Iñaki García Etxebarria and Jonas Platte
License    : LGPL-2.1
Maintainer : Iñaki García Etxebarria (garetxe@gmail.com)
-}

module GI.Gtk.Objects.Socket
    ( 

-- * Exported types
    Socket(..)                              ,
    SocketK                                 ,
    toSocket                                ,
    noSocket                                ,


 -- * Methods
-- ** socketAddId
    SocketAddIdMethodInfo                   ,
    socketAddId                             ,


-- ** socketGetId
    SocketGetIdMethodInfo                   ,
    socketGetId                             ,


-- ** socketGetPlugWindow
    SocketGetPlugWindowMethodInfo           ,
    socketGetPlugWindow                     ,


-- ** socketNew
    socketNew                               ,




 -- * Signals
-- ** PlugAdded
    SocketPlugAddedCallback                 ,
    SocketPlugAddedCallbackC                ,
    SocketPlugAddedSignalInfo               ,
    afterSocketPlugAdded                    ,
    mkSocketPlugAddedCallback               ,
    noSocketPlugAddedCallback               ,
    onSocketPlugAdded                       ,
    socketPlugAddedCallbackWrapper          ,
    socketPlugAddedClosure                  ,


-- ** PlugRemoved
    SocketPlugRemovedCallback               ,
    SocketPlugRemovedCallbackC              ,
    SocketPlugRemovedSignalInfo             ,
    afterSocketPlugRemoved                  ,
    mkSocketPlugRemovedCallback             ,
    noSocketPlugRemovedCallback             ,
    onSocketPlugRemoved                     ,
    socketPlugRemovedCallbackWrapper        ,
    socketPlugRemovedClosure                ,




    ) where

import Data.GI.Base.ShortPrelude

import qualified Data.GI.Base.Attributes as GI.Attributes
import qualified Data.Text as T
import qualified Data.ByteString.Char8 as B
import qualified Data.Map as Map

import GI.Gtk.Types
import GI.Gtk.Callbacks
import qualified GI.Atk as Atk
import qualified GI.GObject as GObject
import qualified GI.Gdk as Gdk

newtype Socket = Socket (ForeignPtr Socket)
foreign import ccall "gtk_socket_get_type"
    c_gtk_socket_get_type :: IO GType

type instance ParentTypes Socket = SocketParentTypes
type SocketParentTypes = '[Container, Widget, GObject.Object, Atk.ImplementorIface, Buildable]

instance GObject Socket where
    gobjectIsInitiallyUnowned _ = True
    gobjectType _ = c_gtk_socket_get_type
    

class GObject o => SocketK o
instance (GObject o, IsDescendantOf Socket o) => SocketK o

toSocket :: SocketK o => o -> IO Socket
toSocket = unsafeCastTo Socket

noSocket :: Maybe Socket
noSocket = Nothing

type family ResolveSocketMethod (t :: Symbol) (o :: *) :: * where
    ResolveSocketMethod "activate" o = WidgetActivateMethodInfo
    ResolveSocketMethod "add" o = ContainerAddMethodInfo
    ResolveSocketMethod "addAccelerator" o = WidgetAddAcceleratorMethodInfo
    ResolveSocketMethod "addChild" o = BuildableAddChildMethodInfo
    ResolveSocketMethod "addDeviceEvents" o = WidgetAddDeviceEventsMethodInfo
    ResolveSocketMethod "addEvents" o = WidgetAddEventsMethodInfo
    ResolveSocketMethod "addId" o = SocketAddIdMethodInfo
    ResolveSocketMethod "addMnemonicLabel" o = WidgetAddMnemonicLabelMethodInfo
    ResolveSocketMethod "addTickCallback" o = WidgetAddTickCallbackMethodInfo
    ResolveSocketMethod "bindProperty" o = GObject.ObjectBindPropertyMethodInfo
    ResolveSocketMethod "bindPropertyFull" o = GObject.ObjectBindPropertyFullMethodInfo
    ResolveSocketMethod "canActivateAccel" o = WidgetCanActivateAccelMethodInfo
    ResolveSocketMethod "checkResize" o = ContainerCheckResizeMethodInfo
    ResolveSocketMethod "childFocus" o = WidgetChildFocusMethodInfo
    ResolveSocketMethod "childGetProperty" o = ContainerChildGetPropertyMethodInfo
    ResolveSocketMethod "childNotifyByPspec" o = ContainerChildNotifyByPspecMethodInfo
    ResolveSocketMethod "childSetProperty" o = ContainerChildSetPropertyMethodInfo
    ResolveSocketMethod "childType" o = ContainerChildTypeMethodInfo
    ResolveSocketMethod "classPath" o = WidgetClassPathMethodInfo
    ResolveSocketMethod "computeExpand" o = WidgetComputeExpandMethodInfo
    ResolveSocketMethod "constructChild" o = BuildableConstructChildMethodInfo
    ResolveSocketMethod "createPangoContext" o = WidgetCreatePangoContextMethodInfo
    ResolveSocketMethod "createPangoLayout" o = WidgetCreatePangoLayoutMethodInfo
    ResolveSocketMethod "customFinished" o = BuildableCustomFinishedMethodInfo
    ResolveSocketMethod "customTagEnd" o = BuildableCustomTagEndMethodInfo
    ResolveSocketMethod "customTagStart" o = BuildableCustomTagStartMethodInfo
    ResolveSocketMethod "destroy" o = WidgetDestroyMethodInfo
    ResolveSocketMethod "destroyed" o = WidgetDestroyedMethodInfo
    ResolveSocketMethod "deviceIsShadowed" o = WidgetDeviceIsShadowedMethodInfo
    ResolveSocketMethod "dragBegin" o = WidgetDragBeginMethodInfo
    ResolveSocketMethod "dragBeginWithCoordinates" o = WidgetDragBeginWithCoordinatesMethodInfo
    ResolveSocketMethod "dragCheckThreshold" o = WidgetDragCheckThresholdMethodInfo
    ResolveSocketMethod "dragDestAddImageTargets" o = WidgetDragDestAddImageTargetsMethodInfo
    ResolveSocketMethod "dragDestAddTextTargets" o = WidgetDragDestAddTextTargetsMethodInfo
    ResolveSocketMethod "dragDestAddUriTargets" o = WidgetDragDestAddUriTargetsMethodInfo
    ResolveSocketMethod "dragDestFindTarget" o = WidgetDragDestFindTargetMethodInfo
    ResolveSocketMethod "dragDestGetTargetList" o = WidgetDragDestGetTargetListMethodInfo
    ResolveSocketMethod "dragDestGetTrackMotion" o = WidgetDragDestGetTrackMotionMethodInfo
    ResolveSocketMethod "dragDestSet" o = WidgetDragDestSetMethodInfo
    ResolveSocketMethod "dragDestSetProxy" o = WidgetDragDestSetProxyMethodInfo
    ResolveSocketMethod "dragDestSetTargetList" o = WidgetDragDestSetTargetListMethodInfo
    ResolveSocketMethod "dragDestSetTrackMotion" o = WidgetDragDestSetTrackMotionMethodInfo
    ResolveSocketMethod "dragDestUnset" o = WidgetDragDestUnsetMethodInfo
    ResolveSocketMethod "dragGetData" o = WidgetDragGetDataMethodInfo
    ResolveSocketMethod "dragHighlight" o = WidgetDragHighlightMethodInfo
    ResolveSocketMethod "dragSourceAddImageTargets" o = WidgetDragSourceAddImageTargetsMethodInfo
    ResolveSocketMethod "dragSourceAddTextTargets" o = WidgetDragSourceAddTextTargetsMethodInfo
    ResolveSocketMethod "dragSourceAddUriTargets" o = WidgetDragSourceAddUriTargetsMethodInfo
    ResolveSocketMethod "dragSourceGetTargetList" o = WidgetDragSourceGetTargetListMethodInfo
    ResolveSocketMethod "dragSourceSet" o = WidgetDragSourceSetMethodInfo
    ResolveSocketMethod "dragSourceSetIconGicon" o = WidgetDragSourceSetIconGiconMethodInfo
    ResolveSocketMethod "dragSourceSetIconName" o = WidgetDragSourceSetIconNameMethodInfo
    ResolveSocketMethod "dragSourceSetIconPixbuf" o = WidgetDragSourceSetIconPixbufMethodInfo
    ResolveSocketMethod "dragSourceSetIconStock" o = WidgetDragSourceSetIconStockMethodInfo
    ResolveSocketMethod "dragSourceSetTargetList" o = WidgetDragSourceSetTargetListMethodInfo
    ResolveSocketMethod "dragSourceUnset" o = WidgetDragSourceUnsetMethodInfo
    ResolveSocketMethod "dragUnhighlight" o = WidgetDragUnhighlightMethodInfo
    ResolveSocketMethod "draw" o = WidgetDrawMethodInfo
    ResolveSocketMethod "ensureStyle" o = WidgetEnsureStyleMethodInfo
    ResolveSocketMethod "errorBell" o = WidgetErrorBellMethodInfo
    ResolveSocketMethod "event" o = WidgetEventMethodInfo
    ResolveSocketMethod "forall" o = ContainerForallMethodInfo
    ResolveSocketMethod "forceFloating" o = GObject.ObjectForceFloatingMethodInfo
    ResolveSocketMethod "foreach" o = ContainerForeachMethodInfo
    ResolveSocketMethod "freezeChildNotify" o = WidgetFreezeChildNotifyMethodInfo
    ResolveSocketMethod "freezeNotify" o = GObject.ObjectFreezeNotifyMethodInfo
    ResolveSocketMethod "grabAdd" o = WidgetGrabAddMethodInfo
    ResolveSocketMethod "grabDefault" o = WidgetGrabDefaultMethodInfo
    ResolveSocketMethod "grabFocus" o = WidgetGrabFocusMethodInfo
    ResolveSocketMethod "grabRemove" o = WidgetGrabRemoveMethodInfo
    ResolveSocketMethod "hasDefault" o = WidgetHasDefaultMethodInfo
    ResolveSocketMethod "hasFocus" o = WidgetHasFocusMethodInfo
    ResolveSocketMethod "hasGrab" o = WidgetHasGrabMethodInfo
    ResolveSocketMethod "hasRcStyle" o = WidgetHasRcStyleMethodInfo
    ResolveSocketMethod "hasScreen" o = WidgetHasScreenMethodInfo
    ResolveSocketMethod "hasVisibleFocus" o = WidgetHasVisibleFocusMethodInfo
    ResolveSocketMethod "hide" o = WidgetHideMethodInfo
    ResolveSocketMethod "hideOnDelete" o = WidgetHideOnDeleteMethodInfo
    ResolveSocketMethod "inDestruction" o = WidgetInDestructionMethodInfo
    ResolveSocketMethod "initTemplate" o = WidgetInitTemplateMethodInfo
    ResolveSocketMethod "inputShapeCombineRegion" o = WidgetInputShapeCombineRegionMethodInfo
    ResolveSocketMethod "insertActionGroup" o = WidgetInsertActionGroupMethodInfo
    ResolveSocketMethod "intersect" o = WidgetIntersectMethodInfo
    ResolveSocketMethod "isAncestor" o = WidgetIsAncestorMethodInfo
    ResolveSocketMethod "isComposited" o = WidgetIsCompositedMethodInfo
    ResolveSocketMethod "isDrawable" o = WidgetIsDrawableMethodInfo
    ResolveSocketMethod "isFloating" o = GObject.ObjectIsFloatingMethodInfo
    ResolveSocketMethod "isFocus" o = WidgetIsFocusMethodInfo
    ResolveSocketMethod "isSensitive" o = WidgetIsSensitiveMethodInfo
    ResolveSocketMethod "isToplevel" o = WidgetIsToplevelMethodInfo
    ResolveSocketMethod "isVisible" o = WidgetIsVisibleMethodInfo
    ResolveSocketMethod "keynavFailed" o = WidgetKeynavFailedMethodInfo
    ResolveSocketMethod "listAccelClosures" o = WidgetListAccelClosuresMethodInfo
    ResolveSocketMethod "listActionPrefixes" o = WidgetListActionPrefixesMethodInfo
    ResolveSocketMethod "listMnemonicLabels" o = WidgetListMnemonicLabelsMethodInfo
    ResolveSocketMethod "map" o = WidgetMapMethodInfo
    ResolveSocketMethod "mnemonicActivate" o = WidgetMnemonicActivateMethodInfo
    ResolveSocketMethod "modifyBase" o = WidgetModifyBaseMethodInfo
    ResolveSocketMethod "modifyBg" o = WidgetModifyBgMethodInfo
    ResolveSocketMethod "modifyCursor" o = WidgetModifyCursorMethodInfo
    ResolveSocketMethod "modifyFg" o = WidgetModifyFgMethodInfo
    ResolveSocketMethod "modifyFont" o = WidgetModifyFontMethodInfo
    ResolveSocketMethod "modifyStyle" o = WidgetModifyStyleMethodInfo
    ResolveSocketMethod "modifyText" o = WidgetModifyTextMethodInfo
    ResolveSocketMethod "notify" o = GObject.ObjectNotifyMethodInfo
    ResolveSocketMethod "notifyByPspec" o = GObject.ObjectNotifyByPspecMethodInfo
    ResolveSocketMethod "overrideBackgroundColor" o = WidgetOverrideBackgroundColorMethodInfo
    ResolveSocketMethod "overrideColor" o = WidgetOverrideColorMethodInfo
    ResolveSocketMethod "overrideCursor" o = WidgetOverrideCursorMethodInfo
    ResolveSocketMethod "overrideFont" o = WidgetOverrideFontMethodInfo
    ResolveSocketMethod "overrideSymbolicColor" o = WidgetOverrideSymbolicColorMethodInfo
    ResolveSocketMethod "parserFinished" o = BuildableParserFinishedMethodInfo
    ResolveSocketMethod "path" o = WidgetPathMethodInfo
    ResolveSocketMethod "propagateDraw" o = ContainerPropagateDrawMethodInfo
    ResolveSocketMethod "queueComputeExpand" o = WidgetQueueComputeExpandMethodInfo
    ResolveSocketMethod "queueDraw" o = WidgetQueueDrawMethodInfo
    ResolveSocketMethod "queueDrawArea" o = WidgetQueueDrawAreaMethodInfo
    ResolveSocketMethod "queueDrawRegion" o = WidgetQueueDrawRegionMethodInfo
    ResolveSocketMethod "queueResize" o = WidgetQueueResizeMethodInfo
    ResolveSocketMethod "queueResizeNoRedraw" o = WidgetQueueResizeNoRedrawMethodInfo
    ResolveSocketMethod "realize" o = WidgetRealizeMethodInfo
    ResolveSocketMethod "ref" o = GObject.ObjectRefMethodInfo
    ResolveSocketMethod "refSink" o = GObject.ObjectRefSinkMethodInfo
    ResolveSocketMethod "regionIntersect" o = WidgetRegionIntersectMethodInfo
    ResolveSocketMethod "registerWindow" o = WidgetRegisterWindowMethodInfo
    ResolveSocketMethod "remove" o = ContainerRemoveMethodInfo
    ResolveSocketMethod "removeAccelerator" o = WidgetRemoveAcceleratorMethodInfo
    ResolveSocketMethod "removeMnemonicLabel" o = WidgetRemoveMnemonicLabelMethodInfo
    ResolveSocketMethod "removeTickCallback" o = WidgetRemoveTickCallbackMethodInfo
    ResolveSocketMethod "renderIcon" o = WidgetRenderIconMethodInfo
    ResolveSocketMethod "renderIconPixbuf" o = WidgetRenderIconPixbufMethodInfo
    ResolveSocketMethod "reparent" o = WidgetReparentMethodInfo
    ResolveSocketMethod "replaceData" o = GObject.ObjectReplaceDataMethodInfo
    ResolveSocketMethod "replaceQdata" o = GObject.ObjectReplaceQdataMethodInfo
    ResolveSocketMethod "resetRcStyles" o = WidgetResetRcStylesMethodInfo
    ResolveSocketMethod "resetStyle" o = WidgetResetStyleMethodInfo
    ResolveSocketMethod "resizeChildren" o = ContainerResizeChildrenMethodInfo
    ResolveSocketMethod "runDispose" o = GObject.ObjectRunDisposeMethodInfo
    ResolveSocketMethod "sendExpose" o = WidgetSendExposeMethodInfo
    ResolveSocketMethod "sendFocusChange" o = WidgetSendFocusChangeMethodInfo
    ResolveSocketMethod "shapeCombineRegion" o = WidgetShapeCombineRegionMethodInfo
    ResolveSocketMethod "show" o = WidgetShowMethodInfo
    ResolveSocketMethod "showAll" o = WidgetShowAllMethodInfo
    ResolveSocketMethod "showNow" o = WidgetShowNowMethodInfo
    ResolveSocketMethod "sizeAllocate" o = WidgetSizeAllocateMethodInfo
    ResolveSocketMethod "sizeAllocateWithBaseline" o = WidgetSizeAllocateWithBaselineMethodInfo
    ResolveSocketMethod "sizeRequest" o = WidgetSizeRequestMethodInfo
    ResolveSocketMethod "stealData" o = GObject.ObjectStealDataMethodInfo
    ResolveSocketMethod "stealQdata" o = GObject.ObjectStealQdataMethodInfo
    ResolveSocketMethod "styleAttach" o = WidgetStyleAttachMethodInfo
    ResolveSocketMethod "styleGetProperty" o = WidgetStyleGetPropertyMethodInfo
    ResolveSocketMethod "thawChildNotify" o = WidgetThawChildNotifyMethodInfo
    ResolveSocketMethod "thawNotify" o = GObject.ObjectThawNotifyMethodInfo
    ResolveSocketMethod "translateCoordinates" o = WidgetTranslateCoordinatesMethodInfo
    ResolveSocketMethod "triggerTooltipQuery" o = WidgetTriggerTooltipQueryMethodInfo
    ResolveSocketMethod "unmap" o = WidgetUnmapMethodInfo
    ResolveSocketMethod "unparent" o = WidgetUnparentMethodInfo
    ResolveSocketMethod "unrealize" o = WidgetUnrealizeMethodInfo
    ResolveSocketMethod "unref" o = GObject.ObjectUnrefMethodInfo
    ResolveSocketMethod "unregisterWindow" o = WidgetUnregisterWindowMethodInfo
    ResolveSocketMethod "unsetFocusChain" o = ContainerUnsetFocusChainMethodInfo
    ResolveSocketMethod "unsetStateFlags" o = WidgetUnsetStateFlagsMethodInfo
    ResolveSocketMethod "watchClosure" o = GObject.ObjectWatchClosureMethodInfo
    ResolveSocketMethod "getAccessible" o = WidgetGetAccessibleMethodInfo
    ResolveSocketMethod "getActionGroup" o = WidgetGetActionGroupMethodInfo
    ResolveSocketMethod "getAllocatedBaseline" o = WidgetGetAllocatedBaselineMethodInfo
    ResolveSocketMethod "getAllocatedHeight" o = WidgetGetAllocatedHeightMethodInfo
    ResolveSocketMethod "getAllocatedWidth" o = WidgetGetAllocatedWidthMethodInfo
    ResolveSocketMethod "getAllocation" o = WidgetGetAllocationMethodInfo
    ResolveSocketMethod "getAncestor" o = WidgetGetAncestorMethodInfo
    ResolveSocketMethod "getAppPaintable" o = WidgetGetAppPaintableMethodInfo
    ResolveSocketMethod "getBorderWidth" o = ContainerGetBorderWidthMethodInfo
    ResolveSocketMethod "getCanDefault" o = WidgetGetCanDefaultMethodInfo
    ResolveSocketMethod "getCanFocus" o = WidgetGetCanFocusMethodInfo
    ResolveSocketMethod "getChildRequisition" o = WidgetGetChildRequisitionMethodInfo
    ResolveSocketMethod "getChildVisible" o = WidgetGetChildVisibleMethodInfo
    ResolveSocketMethod "getChildren" o = ContainerGetChildrenMethodInfo
    ResolveSocketMethod "getClip" o = WidgetGetClipMethodInfo
    ResolveSocketMethod "getClipboard" o = WidgetGetClipboardMethodInfo
    ResolveSocketMethod "getCompositeName" o = WidgetGetCompositeNameMethodInfo
    ResolveSocketMethod "getData" o = GObject.ObjectGetDataMethodInfo
    ResolveSocketMethod "getDeviceEnabled" o = WidgetGetDeviceEnabledMethodInfo
    ResolveSocketMethod "getDeviceEvents" o = WidgetGetDeviceEventsMethodInfo
    ResolveSocketMethod "getDirection" o = WidgetGetDirectionMethodInfo
    ResolveSocketMethod "getDisplay" o = WidgetGetDisplayMethodInfo
    ResolveSocketMethod "getDoubleBuffered" o = WidgetGetDoubleBufferedMethodInfo
    ResolveSocketMethod "getEvents" o = WidgetGetEventsMethodInfo
    ResolveSocketMethod "getFocusChain" o = ContainerGetFocusChainMethodInfo
    ResolveSocketMethod "getFocusChild" o = ContainerGetFocusChildMethodInfo
    ResolveSocketMethod "getFocusHadjustment" o = ContainerGetFocusHadjustmentMethodInfo
    ResolveSocketMethod "getFocusVadjustment" o = ContainerGetFocusVadjustmentMethodInfo
    ResolveSocketMethod "getFontMap" o = WidgetGetFontMapMethodInfo
    ResolveSocketMethod "getFontOptions" o = WidgetGetFontOptionsMethodInfo
    ResolveSocketMethod "getFrameClock" o = WidgetGetFrameClockMethodInfo
    ResolveSocketMethod "getHalign" o = WidgetGetHalignMethodInfo
    ResolveSocketMethod "getHasTooltip" o = WidgetGetHasTooltipMethodInfo
    ResolveSocketMethod "getHasWindow" o = WidgetGetHasWindowMethodInfo
    ResolveSocketMethod "getHexpand" o = WidgetGetHexpandMethodInfo
    ResolveSocketMethod "getHexpandSet" o = WidgetGetHexpandSetMethodInfo
    ResolveSocketMethod "getId" o = SocketGetIdMethodInfo
    ResolveSocketMethod "getInternalChild" o = BuildableGetInternalChildMethodInfo
    ResolveSocketMethod "getMapped" o = WidgetGetMappedMethodInfo
    ResolveSocketMethod "getMarginBottom" o = WidgetGetMarginBottomMethodInfo
    ResolveSocketMethod "getMarginEnd" o = WidgetGetMarginEndMethodInfo
    ResolveSocketMethod "getMarginLeft" o = WidgetGetMarginLeftMethodInfo
    ResolveSocketMethod "getMarginRight" o = WidgetGetMarginRightMethodInfo
    ResolveSocketMethod "getMarginStart" o = WidgetGetMarginStartMethodInfo
    ResolveSocketMethod "getMarginTop" o = WidgetGetMarginTopMethodInfo
    ResolveSocketMethod "getModifierMask" o = WidgetGetModifierMaskMethodInfo
    ResolveSocketMethod "getModifierStyle" o = WidgetGetModifierStyleMethodInfo
    ResolveSocketMethod "getNoShowAll" o = WidgetGetNoShowAllMethodInfo
    ResolveSocketMethod "getOpacity" o = WidgetGetOpacityMethodInfo
    ResolveSocketMethod "getPangoContext" o = WidgetGetPangoContextMethodInfo
    ResolveSocketMethod "getParent" o = WidgetGetParentMethodInfo
    ResolveSocketMethod "getParentWindow" o = WidgetGetParentWindowMethodInfo
    ResolveSocketMethod "getPath" o = WidgetGetPathMethodInfo
    ResolveSocketMethod "getPathForChild" o = ContainerGetPathForChildMethodInfo
    ResolveSocketMethod "getPlugWindow" o = SocketGetPlugWindowMethodInfo
    ResolveSocketMethod "getPointer" o = WidgetGetPointerMethodInfo
    ResolveSocketMethod "getPreferredHeight" o = WidgetGetPreferredHeightMethodInfo
    ResolveSocketMethod "getPreferredHeightAndBaselineForWidth" o = WidgetGetPreferredHeightAndBaselineForWidthMethodInfo
    ResolveSocketMethod "getPreferredHeightForWidth" o = WidgetGetPreferredHeightForWidthMethodInfo
    ResolveSocketMethod "getPreferredSize" o = WidgetGetPreferredSizeMethodInfo
    ResolveSocketMethod "getPreferredWidth" o = WidgetGetPreferredWidthMethodInfo
    ResolveSocketMethod "getPreferredWidthForHeight" o = WidgetGetPreferredWidthForHeightMethodInfo
    ResolveSocketMethod "getProperty" o = GObject.ObjectGetPropertyMethodInfo
    ResolveSocketMethod "getQdata" o = GObject.ObjectGetQdataMethodInfo
    ResolveSocketMethod "getRealized" o = WidgetGetRealizedMethodInfo
    ResolveSocketMethod "getReceivesDefault" o = WidgetGetReceivesDefaultMethodInfo
    ResolveSocketMethod "getRequestMode" o = WidgetGetRequestModeMethodInfo
    ResolveSocketMethod "getRequisition" o = WidgetGetRequisitionMethodInfo
    ResolveSocketMethod "getResizeMode" o = ContainerGetResizeModeMethodInfo
    ResolveSocketMethod "getRootWindow" o = WidgetGetRootWindowMethodInfo
    ResolveSocketMethod "getScaleFactor" o = WidgetGetScaleFactorMethodInfo
    ResolveSocketMethod "getScreen" o = WidgetGetScreenMethodInfo
    ResolveSocketMethod "getSensitive" o = WidgetGetSensitiveMethodInfo
    ResolveSocketMethod "getSettings" o = WidgetGetSettingsMethodInfo
    ResolveSocketMethod "getSizeRequest" o = WidgetGetSizeRequestMethodInfo
    ResolveSocketMethod "getState" o = WidgetGetStateMethodInfo
    ResolveSocketMethod "getStateFlags" o = WidgetGetStateFlagsMethodInfo
    ResolveSocketMethod "getStyle" o = WidgetGetStyleMethodInfo
    ResolveSocketMethod "getStyleContext" o = WidgetGetStyleContextMethodInfo
    ResolveSocketMethod "getSupportMultidevice" o = WidgetGetSupportMultideviceMethodInfo
    ResolveSocketMethod "getTemplateChild" o = WidgetGetTemplateChildMethodInfo
    ResolveSocketMethod "getTooltipMarkup" o = WidgetGetTooltipMarkupMethodInfo
    ResolveSocketMethod "getTooltipText" o = WidgetGetTooltipTextMethodInfo
    ResolveSocketMethod "getTooltipWindow" o = WidgetGetTooltipWindowMethodInfo
    ResolveSocketMethod "getToplevel" o = WidgetGetToplevelMethodInfo
    ResolveSocketMethod "getValign" o = WidgetGetValignMethodInfo
    ResolveSocketMethod "getValignWithBaseline" o = WidgetGetValignWithBaselineMethodInfo
    ResolveSocketMethod "getVexpand" o = WidgetGetVexpandMethodInfo
    ResolveSocketMethod "getVexpandSet" o = WidgetGetVexpandSetMethodInfo
    ResolveSocketMethod "getVisible" o = WidgetGetVisibleMethodInfo
    ResolveSocketMethod "getVisual" o = WidgetGetVisualMethodInfo
    ResolveSocketMethod "getWindow" o = WidgetGetWindowMethodInfo
    ResolveSocketMethod "setAccelPath" o = WidgetSetAccelPathMethodInfo
    ResolveSocketMethod "setAllocation" o = WidgetSetAllocationMethodInfo
    ResolveSocketMethod "setAppPaintable" o = WidgetSetAppPaintableMethodInfo
    ResolveSocketMethod "setBorderWidth" o = ContainerSetBorderWidthMethodInfo
    ResolveSocketMethod "setBuildableProperty" o = BuildableSetBuildablePropertyMethodInfo
    ResolveSocketMethod "setCanDefault" o = WidgetSetCanDefaultMethodInfo
    ResolveSocketMethod "setCanFocus" o = WidgetSetCanFocusMethodInfo
    ResolveSocketMethod "setChildVisible" o = WidgetSetChildVisibleMethodInfo
    ResolveSocketMethod "setClip" o = WidgetSetClipMethodInfo
    ResolveSocketMethod "setCompositeName" o = WidgetSetCompositeNameMethodInfo
    ResolveSocketMethod "setData" o = GObject.ObjectSetDataMethodInfo
    ResolveSocketMethod "setDeviceEnabled" o = WidgetSetDeviceEnabledMethodInfo
    ResolveSocketMethod "setDeviceEvents" o = WidgetSetDeviceEventsMethodInfo
    ResolveSocketMethod "setDirection" o = WidgetSetDirectionMethodInfo
    ResolveSocketMethod "setDoubleBuffered" o = WidgetSetDoubleBufferedMethodInfo
    ResolveSocketMethod "setEvents" o = WidgetSetEventsMethodInfo
    ResolveSocketMethod "setFocusChain" o = ContainerSetFocusChainMethodInfo
    ResolveSocketMethod "setFocusChild" o = ContainerSetFocusChildMethodInfo
    ResolveSocketMethod "setFocusHadjustment" o = ContainerSetFocusHadjustmentMethodInfo
    ResolveSocketMethod "setFocusVadjustment" o = ContainerSetFocusVadjustmentMethodInfo
    ResolveSocketMethod "setFontMap" o = WidgetSetFontMapMethodInfo
    ResolveSocketMethod "setFontOptions" o = WidgetSetFontOptionsMethodInfo
    ResolveSocketMethod "setHalign" o = WidgetSetHalignMethodInfo
    ResolveSocketMethod "setHasTooltip" o = WidgetSetHasTooltipMethodInfo
    ResolveSocketMethod "setHasWindow" o = WidgetSetHasWindowMethodInfo
    ResolveSocketMethod "setHexpand" o = WidgetSetHexpandMethodInfo
    ResolveSocketMethod "setHexpandSet" o = WidgetSetHexpandSetMethodInfo
    ResolveSocketMethod "setMapped" o = WidgetSetMappedMethodInfo
    ResolveSocketMethod "setMarginBottom" o = WidgetSetMarginBottomMethodInfo
    ResolveSocketMethod "setMarginEnd" o = WidgetSetMarginEndMethodInfo
    ResolveSocketMethod "setMarginLeft" o = WidgetSetMarginLeftMethodInfo
    ResolveSocketMethod "setMarginRight" o = WidgetSetMarginRightMethodInfo
    ResolveSocketMethod "setMarginStart" o = WidgetSetMarginStartMethodInfo
    ResolveSocketMethod "setMarginTop" o = WidgetSetMarginTopMethodInfo
    ResolveSocketMethod "setNoShowAll" o = WidgetSetNoShowAllMethodInfo
    ResolveSocketMethod "setOpacity" o = WidgetSetOpacityMethodInfo
    ResolveSocketMethod "setParent" o = WidgetSetParentMethodInfo
    ResolveSocketMethod "setParentWindow" o = WidgetSetParentWindowMethodInfo
    ResolveSocketMethod "setProperty" o = GObject.ObjectSetPropertyMethodInfo
    ResolveSocketMethod "setRealized" o = WidgetSetRealizedMethodInfo
    ResolveSocketMethod "setReallocateRedraws" o = ContainerSetReallocateRedrawsMethodInfo
    ResolveSocketMethod "setReceivesDefault" o = WidgetSetReceivesDefaultMethodInfo
    ResolveSocketMethod "setRedrawOnAllocate" o = WidgetSetRedrawOnAllocateMethodInfo
    ResolveSocketMethod "setResizeMode" o = ContainerSetResizeModeMethodInfo
    ResolveSocketMethod "setSensitive" o = WidgetSetSensitiveMethodInfo
    ResolveSocketMethod "setSizeRequest" o = WidgetSetSizeRequestMethodInfo
    ResolveSocketMethod "setState" o = WidgetSetStateMethodInfo
    ResolveSocketMethod "setStateFlags" o = WidgetSetStateFlagsMethodInfo
    ResolveSocketMethod "setStyle" o = WidgetSetStyleMethodInfo
    ResolveSocketMethod "setSupportMultidevice" o = WidgetSetSupportMultideviceMethodInfo
    ResolveSocketMethod "setTooltipMarkup" o = WidgetSetTooltipMarkupMethodInfo
    ResolveSocketMethod "setTooltipText" o = WidgetSetTooltipTextMethodInfo
    ResolveSocketMethod "setTooltipWindow" o = WidgetSetTooltipWindowMethodInfo
    ResolveSocketMethod "setValign" o = WidgetSetValignMethodInfo
    ResolveSocketMethod "setVexpand" o = WidgetSetVexpandMethodInfo
    ResolveSocketMethod "setVexpandSet" o = WidgetSetVexpandSetMethodInfo
    ResolveSocketMethod "setVisible" o = WidgetSetVisibleMethodInfo
    ResolveSocketMethod "setVisual" o = WidgetSetVisualMethodInfo
    ResolveSocketMethod "setWindow" o = WidgetSetWindowMethodInfo
    ResolveSocketMethod l o = MethodResolutionFailed l o

instance (info ~ ResolveSocketMethod t Socket, MethodInfo info Socket p) => IsLabelProxy t (Socket -> p) where
    fromLabelProxy _ = overloadedMethod (MethodProxy :: MethodProxy info)

#if MIN_VERSION_base(4,9,0)
instance (info ~ ResolveSocketMethod t Socket, MethodInfo info Socket p) => IsLabel t (Socket -> p) where
    fromLabel _ = overloadedMethod (MethodProxy :: MethodProxy info)
#endif

-- signal Socket::plug-added
type SocketPlugAddedCallback =
    IO ()

noSocketPlugAddedCallback :: Maybe SocketPlugAddedCallback
noSocketPlugAddedCallback = Nothing

type SocketPlugAddedCallbackC =
    Ptr () ->                               -- object
    Ptr () ->                               -- user_data
    IO ()

foreign import ccall "wrapper"
    mkSocketPlugAddedCallback :: SocketPlugAddedCallbackC -> IO (FunPtr SocketPlugAddedCallbackC)

socketPlugAddedClosure :: SocketPlugAddedCallback -> IO Closure
socketPlugAddedClosure cb = newCClosure =<< mkSocketPlugAddedCallback wrapped
    where wrapped = socketPlugAddedCallbackWrapper cb

socketPlugAddedCallbackWrapper ::
    SocketPlugAddedCallback ->
    Ptr () ->
    Ptr () ->
    IO ()
socketPlugAddedCallbackWrapper _cb _ _ = do
    _cb 

onSocketPlugAdded :: (GObject a, MonadIO m) => a -> SocketPlugAddedCallback -> m SignalHandlerId
onSocketPlugAdded obj cb = liftIO $ connectSocketPlugAdded obj cb SignalConnectBefore
afterSocketPlugAdded :: (GObject a, MonadIO m) => a -> SocketPlugAddedCallback -> m SignalHandlerId
afterSocketPlugAdded obj cb = connectSocketPlugAdded obj cb SignalConnectAfter

connectSocketPlugAdded :: (GObject a, MonadIO m) =>
                          a -> SocketPlugAddedCallback -> SignalConnectMode -> m SignalHandlerId
connectSocketPlugAdded obj cb after = liftIO $ do
    cb' <- mkSocketPlugAddedCallback (socketPlugAddedCallbackWrapper cb)
    connectSignalFunPtr obj "plug-added" cb' after

-- signal Socket::plug-removed
type SocketPlugRemovedCallback =
    IO Bool

noSocketPlugRemovedCallback :: Maybe SocketPlugRemovedCallback
noSocketPlugRemovedCallback = Nothing

type SocketPlugRemovedCallbackC =
    Ptr () ->                               -- object
    Ptr () ->                               -- user_data
    IO CInt

foreign import ccall "wrapper"
    mkSocketPlugRemovedCallback :: SocketPlugRemovedCallbackC -> IO (FunPtr SocketPlugRemovedCallbackC)

socketPlugRemovedClosure :: SocketPlugRemovedCallback -> IO Closure
socketPlugRemovedClosure cb = newCClosure =<< mkSocketPlugRemovedCallback wrapped
    where wrapped = socketPlugRemovedCallbackWrapper cb

socketPlugRemovedCallbackWrapper ::
    SocketPlugRemovedCallback ->
    Ptr () ->
    Ptr () ->
    IO CInt
socketPlugRemovedCallbackWrapper _cb _ _ = do
    result <- _cb 
    let result' = (fromIntegral . fromEnum) result
    return result'

onSocketPlugRemoved :: (GObject a, MonadIO m) => a -> SocketPlugRemovedCallback -> m SignalHandlerId
onSocketPlugRemoved obj cb = liftIO $ connectSocketPlugRemoved obj cb SignalConnectBefore
afterSocketPlugRemoved :: (GObject a, MonadIO m) => a -> SocketPlugRemovedCallback -> m SignalHandlerId
afterSocketPlugRemoved obj cb = connectSocketPlugRemoved obj cb SignalConnectAfter

connectSocketPlugRemoved :: (GObject a, MonadIO m) =>
                            a -> SocketPlugRemovedCallback -> SignalConnectMode -> m SignalHandlerId
connectSocketPlugRemoved obj cb after = liftIO $ do
    cb' <- mkSocketPlugRemovedCallback (socketPlugRemovedCallbackWrapper cb)
    connectSignalFunPtr obj "plug-removed" cb' after

type instance AttributeList Socket = SocketAttributeList
type SocketAttributeList = ('[ '("appPaintable", WidgetAppPaintablePropertyInfo), '("borderWidth", ContainerBorderWidthPropertyInfo), '("canDefault", WidgetCanDefaultPropertyInfo), '("canFocus", WidgetCanFocusPropertyInfo), '("child", ContainerChildPropertyInfo), '("compositeChild", WidgetCompositeChildPropertyInfo), '("doubleBuffered", WidgetDoubleBufferedPropertyInfo), '("events", WidgetEventsPropertyInfo), '("expand", WidgetExpandPropertyInfo), '("halign", WidgetHalignPropertyInfo), '("hasDefault", WidgetHasDefaultPropertyInfo), '("hasFocus", WidgetHasFocusPropertyInfo), '("hasTooltip", WidgetHasTooltipPropertyInfo), '("heightRequest", WidgetHeightRequestPropertyInfo), '("hexpand", WidgetHexpandPropertyInfo), '("hexpandSet", WidgetHexpandSetPropertyInfo), '("isFocus", WidgetIsFocusPropertyInfo), '("margin", WidgetMarginPropertyInfo), '("marginBottom", WidgetMarginBottomPropertyInfo), '("marginEnd", WidgetMarginEndPropertyInfo), '("marginLeft", WidgetMarginLeftPropertyInfo), '("marginRight", WidgetMarginRightPropertyInfo), '("marginStart", WidgetMarginStartPropertyInfo), '("marginTop", WidgetMarginTopPropertyInfo), '("name", WidgetNamePropertyInfo), '("noShowAll", WidgetNoShowAllPropertyInfo), '("opacity", WidgetOpacityPropertyInfo), '("parent", WidgetParentPropertyInfo), '("receivesDefault", WidgetReceivesDefaultPropertyInfo), '("resizeMode", ContainerResizeModePropertyInfo), '("scaleFactor", WidgetScaleFactorPropertyInfo), '("sensitive", WidgetSensitivePropertyInfo), '("style", WidgetStylePropertyInfo), '("tooltipMarkup", WidgetTooltipMarkupPropertyInfo), '("tooltipText", WidgetTooltipTextPropertyInfo), '("valign", WidgetValignPropertyInfo), '("vexpand", WidgetVexpandPropertyInfo), '("vexpandSet", WidgetVexpandSetPropertyInfo), '("visible", WidgetVisiblePropertyInfo), '("widthRequest", WidgetWidthRequestPropertyInfo), '("window", WidgetWindowPropertyInfo)] :: [(Symbol, *)])

data SocketPlugAddedSignalInfo
instance SignalInfo SocketPlugAddedSignalInfo where
    type HaskellCallbackType SocketPlugAddedSignalInfo = SocketPlugAddedCallback
    connectSignal _ = connectSocketPlugAdded

data SocketPlugRemovedSignalInfo
instance SignalInfo SocketPlugRemovedSignalInfo where
    type HaskellCallbackType SocketPlugRemovedSignalInfo = SocketPlugRemovedCallback
    connectSignal _ = connectSocketPlugRemoved

type instance SignalList Socket = SocketSignalList
type SocketSignalList = ('[ '("accelClosuresChanged", WidgetAccelClosuresChangedSignalInfo), '("add", ContainerAddSignalInfo), '("buttonPressEvent", WidgetButtonPressEventSignalInfo), '("buttonReleaseEvent", WidgetButtonReleaseEventSignalInfo), '("canActivateAccel", WidgetCanActivateAccelSignalInfo), '("checkResize", ContainerCheckResizeSignalInfo), '("childNotify", WidgetChildNotifySignalInfo), '("compositedChanged", WidgetCompositedChangedSignalInfo), '("configureEvent", WidgetConfigureEventSignalInfo), '("damageEvent", WidgetDamageEventSignalInfo), '("deleteEvent", WidgetDeleteEventSignalInfo), '("destroy", WidgetDestroySignalInfo), '("destroyEvent", WidgetDestroyEventSignalInfo), '("directionChanged", WidgetDirectionChangedSignalInfo), '("dragBegin", WidgetDragBeginSignalInfo), '("dragDataDelete", WidgetDragDataDeleteSignalInfo), '("dragDataGet", WidgetDragDataGetSignalInfo), '("dragDataReceived", WidgetDragDataReceivedSignalInfo), '("dragDrop", WidgetDragDropSignalInfo), '("dragEnd", WidgetDragEndSignalInfo), '("dragFailed", WidgetDragFailedSignalInfo), '("dragLeave", WidgetDragLeaveSignalInfo), '("dragMotion", WidgetDragMotionSignalInfo), '("draw", WidgetDrawSignalInfo), '("enterNotifyEvent", WidgetEnterNotifyEventSignalInfo), '("event", WidgetEventSignalInfo), '("eventAfter", WidgetEventAfterSignalInfo), '("focus", WidgetFocusSignalInfo), '("focusInEvent", WidgetFocusInEventSignalInfo), '("focusOutEvent", WidgetFocusOutEventSignalInfo), '("grabBrokenEvent", WidgetGrabBrokenEventSignalInfo), '("grabFocus", WidgetGrabFocusSignalInfo), '("grabNotify", WidgetGrabNotifySignalInfo), '("hide", WidgetHideSignalInfo), '("hierarchyChanged", WidgetHierarchyChangedSignalInfo), '("keyPressEvent", WidgetKeyPressEventSignalInfo), '("keyReleaseEvent", WidgetKeyReleaseEventSignalInfo), '("keynavFailed", WidgetKeynavFailedSignalInfo), '("leaveNotifyEvent", WidgetLeaveNotifyEventSignalInfo), '("map", WidgetMapSignalInfo), '("mapEvent", WidgetMapEventSignalInfo), '("mnemonicActivate", WidgetMnemonicActivateSignalInfo), '("motionNotifyEvent", WidgetMotionNotifyEventSignalInfo), '("moveFocus", WidgetMoveFocusSignalInfo), '("notify", GObject.ObjectNotifySignalInfo), '("parentSet", WidgetParentSetSignalInfo), '("plugAdded", SocketPlugAddedSignalInfo), '("plugRemoved", SocketPlugRemovedSignalInfo), '("popupMenu", WidgetPopupMenuSignalInfo), '("propertyNotifyEvent", WidgetPropertyNotifyEventSignalInfo), '("proximityInEvent", WidgetProximityInEventSignalInfo), '("proximityOutEvent", WidgetProximityOutEventSignalInfo), '("queryTooltip", WidgetQueryTooltipSignalInfo), '("realize", WidgetRealizeSignalInfo), '("remove", ContainerRemoveSignalInfo), '("screenChanged", WidgetScreenChangedSignalInfo), '("scrollEvent", WidgetScrollEventSignalInfo), '("selectionClearEvent", WidgetSelectionClearEventSignalInfo), '("selectionGet", WidgetSelectionGetSignalInfo), '("selectionNotifyEvent", WidgetSelectionNotifyEventSignalInfo), '("selectionReceived", WidgetSelectionReceivedSignalInfo), '("selectionRequestEvent", WidgetSelectionRequestEventSignalInfo), '("setFocusChild", ContainerSetFocusChildSignalInfo), '("show", WidgetShowSignalInfo), '("showHelp", WidgetShowHelpSignalInfo), '("sizeAllocate", WidgetSizeAllocateSignalInfo), '("stateChanged", WidgetStateChangedSignalInfo), '("stateFlagsChanged", WidgetStateFlagsChangedSignalInfo), '("styleSet", WidgetStyleSetSignalInfo), '("styleUpdated", WidgetStyleUpdatedSignalInfo), '("touchEvent", WidgetTouchEventSignalInfo), '("unmap", WidgetUnmapSignalInfo), '("unmapEvent", WidgetUnmapEventSignalInfo), '("unrealize", WidgetUnrealizeSignalInfo), '("visibilityNotifyEvent", WidgetVisibilityNotifyEventSignalInfo), '("windowStateEvent", WidgetWindowStateEventSignalInfo)] :: [(Symbol, *)])

-- method Socket::new
-- method type : Constructor
-- Args : []
-- Lengths : []
-- returnType : Just (TInterface "Gtk" "Socket")
-- throws : False
-- Skip return : False

foreign import ccall "gtk_socket_new" gtk_socket_new :: 
    IO (Ptr Socket)


socketNew ::
    (MonadIO m) =>
    m Socket                                -- result
socketNew  = liftIO $ do
    result <- gtk_socket_new
    checkUnexpectedReturnNULL "gtk_socket_new" result
    result' <- (newObject Socket) result
    return result'

-- method Socket::add_id
-- method type : OrdinaryMethod
-- Args : [Arg {argCName = "_obj", argType = TInterface "Gtk" "Socket", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing},Arg {argCName = "window", argType = TBasicType TULong, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing}]
-- Lengths : []
-- returnType : Nothing
-- throws : False
-- Skip return : False

foreign import ccall "gtk_socket_add_id" gtk_socket_add_id :: 
    Ptr Socket ->                           -- _obj : TInterface "Gtk" "Socket"
    CULong ->                               -- window : TBasicType TULong
    IO ()


socketAddId ::
    (MonadIO m, SocketK a) =>
    a                                       -- _obj
    -> CULong                               -- window
    -> m ()                                 -- result
socketAddId _obj window = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    gtk_socket_add_id _obj' window
    touchManagedPtr _obj
    return ()

data SocketAddIdMethodInfo
instance (signature ~ (CULong -> m ()), MonadIO m, SocketK a) => MethodInfo SocketAddIdMethodInfo a signature where
    overloadedMethod _ = socketAddId

-- method Socket::get_id
-- method type : OrdinaryMethod
-- Args : [Arg {argCName = "_obj", argType = TInterface "Gtk" "Socket", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing}]
-- Lengths : []
-- returnType : Just (TBasicType TULong)
-- throws : False
-- Skip return : False

foreign import ccall "gtk_socket_get_id" gtk_socket_get_id :: 
    Ptr Socket ->                           -- _obj : TInterface "Gtk" "Socket"
    IO CULong


socketGetId ::
    (MonadIO m, SocketK a) =>
    a                                       -- _obj
    -> m CULong                             -- result
socketGetId _obj = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    result <- gtk_socket_get_id _obj'
    touchManagedPtr _obj
    return result

data SocketGetIdMethodInfo
instance (signature ~ (m CULong), MonadIO m, SocketK a) => MethodInfo SocketGetIdMethodInfo a signature where
    overloadedMethod _ = socketGetId

-- method Socket::get_plug_window
-- method type : OrdinaryMethod
-- Args : [Arg {argCName = "_obj", argType = TInterface "Gtk" "Socket", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing}]
-- Lengths : []
-- returnType : Just (TInterface "Gdk" "Window")
-- throws : False
-- Skip return : False

foreign import ccall "gtk_socket_get_plug_window" gtk_socket_get_plug_window :: 
    Ptr Socket ->                           -- _obj : TInterface "Gtk" "Socket"
    IO (Ptr Gdk.Window)


socketGetPlugWindow ::
    (MonadIO m, SocketK a) =>
    a                                       -- _obj
    -> m Gdk.Window                         -- result
socketGetPlugWindow _obj = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    result <- gtk_socket_get_plug_window _obj'
    checkUnexpectedReturnNULL "gtk_socket_get_plug_window" result
    result' <- (newObject Gdk.Window) result
    touchManagedPtr _obj
    return result'

data SocketGetPlugWindowMethodInfo
instance (signature ~ (m Gdk.Window), MonadIO m, SocketK a) => MethodInfo SocketGetPlugWindowMethodInfo a signature where
    overloadedMethod _ = socketGetPlugWindow


